@@ -31,7 +31,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_workdocs.type_defs import (
     DescribeActivitiesResponseTypeDef,
@@ -81,7 +81,7 @@ class DescribeActivitiesPaginator(Boto3Paginator):
         UserId: str = None,
         IncludeIndirectActivities: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeActivitiesResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeActivitiesResponseTypeDef]:
         """
         [DescribeActivities.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities.paginate)
         """
@@ -98,7 +98,7 @@ class DescribeCommentsPaginator(Boto3Paginator):
         VersionId: str,
         AuthenticationToken: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeCommentsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeCommentsResponseTypeDef]:
         """
         [DescribeComments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments.paginate)
         """
@@ -116,7 +116,7 @@ class DescribeDocumentVersionsPaginator(Boto3Paginator):
         Include: str = None,
         Fields: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeDocumentVersionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeDocumentVersionsResponseTypeDef]:
         """
         [DescribeDocumentVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions.paginate)
         """
@@ -136,7 +136,7 @@ class DescribeFolderContentsPaginator(Boto3Paginator):
         Type: Literal["ALL", "DOCUMENT", "FOLDER"] = None,
         Include: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeFolderContentsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeFolderContentsResponseTypeDef]:
         """
         [DescribeFolderContents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents.paginate)
         """
@@ -153,7 +153,7 @@ class DescribeGroupsPaginator(Boto3Paginator):
         AuthenticationToken: str = None,
         OrganizationId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeGroupsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeGroupsResponseTypeDef]:
         """
         [DescribeGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups.paginate)
         """
@@ -166,7 +166,7 @@ class DescribeNotificationSubscriptionsPaginator(Boto3Paginator):
 
     def paginate(
         self, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeNotificationSubscriptionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeNotificationSubscriptionsResponseTypeDef]:
         """
         [DescribeNotificationSubscriptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions.paginate)
         """
@@ -183,7 +183,7 @@ class DescribeResourcePermissionsPaginator(Boto3Paginator):
         AuthenticationToken: str = None,
         PrincipalId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeResourcePermissionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeResourcePermissionsResponseTypeDef]:
         """
         [DescribeResourcePermissions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions.paginate)
         """
@@ -196,7 +196,7 @@ class DescribeRootFoldersPaginator(Boto3Paginator):
 
     def paginate(
         self, AuthenticationToken: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeRootFoldersResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeRootFoldersResponseTypeDef]:
         """
         [DescribeRootFolders.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders.paginate)
         """
@@ -220,7 +220,7 @@ class DescribeUsersPaginator(Boto3Paginator):
         ] = None,
         Fields: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeUsersResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeUsersResponseTypeDef]:
         """
         [DescribeUsers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
         """
